# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

SNAKE_TO_CAMEL_CASE_TABLE = {
    "account_id": "accountId",
    "admin_api_key": "adminApiKey",
    "aggregation_window": "aggregationWindow",
    "api_key": "apiKey",
    "api_url": "apiUrl",
    "app_apdex_threshold": "appApdexThreshold",
    "baseline_direction": "baselineDirection",
    "bypass_head_request": "bypassHeadRequest",
    "cacert_file": "cacertFile",
    "channel_ids": "channelIds",
    "close_violations_on_expiration": "closeViolationsOnExpiration",
    "composite_entity_search_query": "compositeEntitySearchQuery",
    "condition_scope": "conditionScope",
    "created_at": "createdAt",
    "dashboard_url": "dashboardUrl",
    "enable_real_user_monitoring": "enableRealUserMonitoring",
    "end_user_apdex_threshold": "endUserApdexThreshold",
    "entity_guids": "entityGuids",
    "entity_search_queries": "entitySearchQueries",
    "expected_groups": "expectedGroups",
    "expiration_duration": "expirationDuration",
    "fill_option": "fillOption",
    "fill_value": "fillValue",
    "gc_metric": "gcMetric",
    "grid_column_count": "gridColumnCount",
    "ignore_overlap": "ignoreOverlap",
    "incident_preference": "incidentPreference",
    "infrastructure_api_url": "infrastructureApiUrl",
    "ingest_type": "ingestType",
    "insecure_skip_verify": "insecureSkipVerify",
    "insights_insert_key": "insightsInsertKey",
    "insights_insert_url": "insightsInsertUrl",
    "insights_query_url": "insightsQueryUrl",
    "integration_provider": "integrationProvider",
    "key_type": "keyType",
    "last_updated": "lastUpdated",
    "metric_description": "metricDescription",
    "monitor_id": "monitorId",
    "nerdgraph_api_url": "nerdgraphApiUrl",
    "open_violation_on_expiration": "openViolationOnExpiration",
    "open_violation_on_group_overlap": "openViolationOnGroupOverlap",
    "plugin_guid": "pluginGuid",
    "plugin_id": "pluginId",
    "policy_id": "policyId",
    "process_where": "processWhere",
    "rule_id": "ruleId",
    "runbook_url": "runbookUrl",
    "scope_account_ids": "scopeAccountIds",
    "sla_threshold": "slaThreshold",
    "synthetics_api_url": "syntheticsApiUrl",
    "treat_redirect_as_failure": "treatRedirectAsFailure",
    "updated_at": "updatedAt",
    "user_defined_metric": "userDefinedMetric",
    "user_defined_value_function": "userDefinedValueFunction",
    "user_id": "userId",
    "validation_string": "validationString",
    "value_function": "valueFunction",
    "verify_ssl": "verifySsl",
    "violation_close_timer": "violationCloseTimer",
    "violation_time_limit": "violationTimeLimit",
    "violation_time_limit_seconds": "violationTimeLimitSeconds",
    "workload_id": "workloadId",
}

CAMEL_TO_SNAKE_CASE_TABLE = {
    "accountId": "account_id",
    "adminApiKey": "admin_api_key",
    "aggregationWindow": "aggregation_window",
    "apiKey": "api_key",
    "apiUrl": "api_url",
    "appApdexThreshold": "app_apdex_threshold",
    "baselineDirection": "baseline_direction",
    "bypassHeadRequest": "bypass_head_request",
    "cacertFile": "cacert_file",
    "channelIds": "channel_ids",
    "closeViolationsOnExpiration": "close_violations_on_expiration",
    "compositeEntitySearchQuery": "composite_entity_search_query",
    "conditionScope": "condition_scope",
    "createdAt": "created_at",
    "dashboardUrl": "dashboard_url",
    "enableRealUserMonitoring": "enable_real_user_monitoring",
    "endUserApdexThreshold": "end_user_apdex_threshold",
    "entityGuids": "entity_guids",
    "entitySearchQueries": "entity_search_queries",
    "expectedGroups": "expected_groups",
    "expirationDuration": "expiration_duration",
    "fillOption": "fill_option",
    "fillValue": "fill_value",
    "gcMetric": "gc_metric",
    "gridColumnCount": "grid_column_count",
    "ignoreOverlap": "ignore_overlap",
    "incidentPreference": "incident_preference",
    "infrastructureApiUrl": "infrastructure_api_url",
    "ingestType": "ingest_type",
    "insecureSkipVerify": "insecure_skip_verify",
    "insightsInsertKey": "insights_insert_key",
    "insightsInsertUrl": "insights_insert_url",
    "insightsQueryUrl": "insights_query_url",
    "integrationProvider": "integration_provider",
    "keyType": "key_type",
    "lastUpdated": "last_updated",
    "metricDescription": "metric_description",
    "monitorId": "monitor_id",
    "nerdgraphApiUrl": "nerdgraph_api_url",
    "openViolationOnExpiration": "open_violation_on_expiration",
    "openViolationOnGroupOverlap": "open_violation_on_group_overlap",
    "pluginGuid": "plugin_guid",
    "pluginId": "plugin_id",
    "policyId": "policy_id",
    "processWhere": "process_where",
    "ruleId": "rule_id",
    "runbookUrl": "runbook_url",
    "scopeAccountIds": "scope_account_ids",
    "slaThreshold": "sla_threshold",
    "syntheticsApiUrl": "synthetics_api_url",
    "treatRedirectAsFailure": "treat_redirect_as_failure",
    "updatedAt": "updated_at",
    "userDefinedMetric": "user_defined_metric",
    "userDefinedValueFunction": "user_defined_value_function",
    "userId": "user_id",
    "validationString": "validation_string",
    "valueFunction": "value_function",
    "verifySsl": "verify_ssl",
    "violationCloseTimer": "violation_close_timer",
    "violationTimeLimit": "violation_time_limit",
    "violationTimeLimitSeconds": "violation_time_limit_seconds",
    "workloadId": "workload_id",
}
